sentry-responsible
==================

sentry-responsible is an extension to Sentry which lets you assign
responsibilities for events.

This extension adds a widget on the sidebar of a event page to mark
team members as being responsible for a event. When working in teams
where everyone has an eye on incoming events that information might
save you some time by recognizing that someone else is already
investigating this issue (if not, then you are the lucky one).


Installation
------------

To install the extension run::

  pip install sentry-responsible

Then restart your Sentry server to activate the plugin.


License
-------

sentry-responsible is licensed under the BSD license.


Resources
---------

Bug tracker
  https://github.com/andialbrecht/sentry-responsible/issues

Source code
  https://github.com/andialbrecht/sentry-responsible/
